# ======================================================================
# Define options
# ======================================================================
set val(chan)           Channel/WirelessChannel    ;# channel type
set val(prop)           Propagation/TwoRayGround   ;# radio-propagation model
set val(netif)          Phy/WirelessPhy            ;# network interface type
set val(mac)            Mac/802_11                 ;# MAC type
set val(ifq)            Queue/DropTail/PriQueue    ;# interface queue type
set val(ll)             LL                         ;# link layer type
set val(ant)            Antenna/OmniAntenna        ;# antenna model
set val(ifqlen)         50                         ;# max packet in ifq
set val(nn)             2                          ;# number of mobilenodes
set val(rp)             AODV                       ;# routing protocol
set val(x)              500   ;# X dimension of the topography
set val(y)              500   ;# Y dimension of the topography

# ======================================================================
# Main Program
# ======================================================================

set distance 100

# Initialize Global Variables
set ns_		[new Simulator]
$ns_ trace-all stdout

# set up adequat rate
Mac/802_11 set dataRate_ 11Mb
Mac/802_11 set basicRate_ 1Mb

# set up topography object
set topo       [new Topography]
$topo load_flatgrid $val(x) $val(y)


# Create God
create-god $val(nn)


#  Create the specified number of mobilenodes [$val(nn)] and "attach" them to the channel. 
#  Here two nodes are created : node(0) and node(1)

# configure node
$ns_ node-config -adhocRouting $val(rp) \
			-llType $val(ll) \
			-macType $val(mac) \
			-ifqType $val(ifq) \
			-ifqLen $val(ifqlen) \
			-antType $val(ant) \
			-propType $val(prop) \
			-phyType $val(netif) \
			-channelType $val(chan) \
			-topoInstance $topo \
			-agentTrace ON \
			-routerTrace OFF \
			-macTrace OFF \
			-movementTrace OFF			
			 
for {set i 0} {$i < $val(nn) } {incr i} {
	set node_($i) [$ns_ node]	
	$node_($i) random-motion 0		;# disable random motion
}


# Provide initial (X,Y, for now Z=0) co-ordinates for mobilenodes
$node_(0) set X_ 0.0
$node_(0) set Y_ 200.0
$node_(0) set Z_ 0.0

$node_(1) set X_ $distance
$node_(1) set Y_ 200.0
$node_(1) set Z_ 0.0

# Define initial node size and color for Nam
$ns_ initial_node_pos $node_(0) 20
$ns_ initial_node_pos $node_(1) 20
$node_(0) color blue
$node_(1) color red
$ns_ at 0.0 "$node_(0) color blue"
$ns_ at 0.0 "$node_(1) color red"


# Setup traffic flow between nodes
# UDP connections between node_(0) and node_(1)
set udp [new Agent/UDP]
$ns_ attach-agent $node_(0) $udp
set null [new Agent/Null]
$ns_ attach-agent $node_(1) $null
$ns_ connect $udp $null
$udp set packetSize_ 1500
$udp set class_ 2

# CBR traffic generation
set cbr [new Application/Traffic/CBR]
$cbr attach-agent $udp
$cbr set packetSize_ 1500
$cbr set rate_ 4.5Mb
$ns_ at 10.0 "$cbr start"


# Tell nodes when the simulation ends
for {set i 0} {$i < $val(nn) } {incr i} {
    $ns_ at 15.0 "$node_($i) reset";
}

$ns_ at 15.0 "stop"
$ns_ at 15.01 "puts \"NS EXITING...\" ; $ns_ halt"
# No NAM trace, and write trace file 
proc stop {} {
    global ns_
    $ns_ flush-trace
    exit 0
}

puts "Starting Simulation..."
$ns_ run


