# ======================================================================
# Define options
# ======================================================================
set val(chan)           Channel/WirelessChannel    ;# channel type
set val(prop)           Propagation/TwoRayGround   ;# radio-propagation model
set val(netif)          Phy/WirelessPhy            ;# network interface type
set val(mac)            Mac/802_11                 ;# MAC type
set val(ifq)            Queue/DropTail/PriQueue    ;# interface queue type
set val(ll)             LL                         ;# link layer type
set val(ant)            Antenna/OmniAntenna        ;# antenna model
set val(ifqlen)         50                         ;# max packet in ifq
set val(nn)             3                          ;# number of mobilenodes
set val(rp)             AODV                       ;# routing protocol
set val(x)              500   ;# X dimension of the topography
set val(y)              500   ;# Y dimension of the topography

# ======================================================================
# Main Program
# ======================================================================

set outfile "out"

# Initialize Global Variables
set ns_		[new Simulator]
set tracefd     [open $outfile.tr w]
set tracenam	[open $outfile.nam w]
$ns_ trace-all $tracefd
$ns_ namtrace-all-wireless $tracenam $val(x) $val(y)

# set up some parameters
Mac/802_11 set dataRate_ 11.0e6

# Comment to reset CSThresh to default :
Phy/WirelessPhy set CSThresh_ 2.28e-11

# Comment to enable RTS/CTS protocol :
#Mac/802_11 set RTSThreshold_ 10000


# set up topography object
set topo       [new Topography]
$topo load_flatgrid $val(x) $val(y)


# Create God
create-god $val(nn)


#  Create the specified number of mobilenodes [$val(nn)] and "attach" them to the channel. 

# configure node
$ns_ node-config -adhocRouting $val(rp) \
			-llType $val(ll) \
			-macType $val(mac) \
			-ifqType $val(ifq) \
			-ifqLen $val(ifqlen) \
			-antType $val(ant) \
			-propType $val(prop) \
			-phyType $val(netif) \
			-channelType $val(chan) \
			-topoInstance $topo \
			-agentTrace ON \
			-routerTrace OFF \
			-macTrace ON \
			-movementTrace OFF			
			 
for {set i 0} {$i < $val(nn) } {incr i} {
	set node_($i) [$ns_ node]	
	$node_($i) random-motion 0		;# disable random motion
}


# Provide initial (X,Y, for now Z=0) co-ordinates for mobilenodes
$node_(0) set X_ 0.0
$node_(0) set Y_ 200.0
$node_(0) set Z_ 0.0

$node_(1) set X_ 200.0
$node_(1) set Y_ 200.0
$node_(1) set Z_ 0.0

$node_(2) set X_ 400.0
$node_(2) set Y_ 200.0
$node_(2) set Z_ 0.0

# Define initial node size and color for Nam
$ns_ initial_node_pos $node_(0) 20
$ns_ initial_node_pos $node_(1) 20
$ns_ initial_node_pos $node_(2) 20
$node_(0) color blue
$node_(1) color red
$node_(2) color green
$ns_ at 0.0 "$node_(0) color blue"
$ns_ at 0.0 "$node_(1) color red"
$ns_ at 0.0 "$node_(2) color green"


# Setup traffic flow between nodes
# TCP connections between node_(0) and node_(1)
set tcp1 [new Agent/TCP]
$tcp1 set class_ 2
$tcp1 set packetSize_ 2000
set sink1 [new Agent/TCPSink]
$ns_ attach-agent $node_(0) $tcp1
$ns_ attach-agent $node_(1) $sink1
$ns_ connect $tcp1 $sink1
set ftp1 [new Application/FTP]
$ftp1 attach-agent $tcp1
$ns_ at 1.0 "$ftp1 start"

# TCP connections between node_(2) and node_(1)
set tcp2 [new Agent/TCP]
$tcp2 set class_ 2
$tcp2 set packetSize_ 2000
set sink2 [new Agent/TCPSink]
$ns_ attach-agent $node_(2) $tcp2
$ns_ attach-agent $node_(1) $sink2
$ns_ connect $tcp2 $sink2
set ftp2 [new Application/FTP]
$ftp2 attach-agent $tcp2
$ns_ at 1.0 "$ftp2 start"


# Tell nodes when the simulation ends
for {set i 0} {$i < $val(nn) } {incr i} {
    $ns_ at 10.0 "$node_($i) reset";
}

$ns_ at 10.0 "stop"
$ns_ at 10.01 "puts \"NS EXITING...\" ; $ns_ halt"
# No NAM trace, and write trace file 
proc stop {} {
    global ns_ tracefd tracenam outfile
    $ns_ flush-trace
    close $tracefd
    close $tracenam
    #exec nam $outfile.nam &
    exit 0
}

puts "Starting Simulation..."
$ns_ run


