# ======================================================================
# Define options
# ======================================================================
set val(chan)           Channel/WirelessChannel    ;# channel type
set val(prop)           Propagation/TwoRayGround   ;# radio-propagation model
set val(netif)          Phy/WirelessPhy            ;# network interface type
set val(mac)            Mac/802_11                 ;# MAC type
set val(ifq)            Queue/DropTail/PriQueue    ;# interface queue type
set val(ll)             LL                         ;# link layer type
set val(ant)            Antenna/OmniAntenna        ;# antenna model
set val(ifqlen)         50                         ;# max packet in ifq
set val(nn)             6                          ;# number of mobilenodes
set val(rp)             AODV                       ;# routing protocol
set val(x)              700   ;# X dimension of the topography
set val(y)              500   ;# Y dimension of the topography

# ======================================================================
# Main Program
# ======================================================================

set outfile "out"

# Initialize Global Variables
set ns_		[new Simulator]
set tracefd     [open $outfile.tr w]
set tracenam	[open $outfile.nam w]
$ns_ trace-all $tracefd
$ns_ namtrace-all-wireless $tracenam $val(x) $val(y)

# set up some parameters
Mac/802_11 set dataRate_ 11Mb
Mac/802_11 set basicRate_ 1Mb
Mac/802_11 set RTSThreshold_ 10000


# set up topography object
set topo       [new Topography]
$topo load_flatgrid $val(x) $val(y)


# Create God
create-god $val(nn)


#  Create the specified number of mobilenodes [$val(nn)] and "attach" them to the channel. 

# configure node
$ns_ node-config -adhocRouting $val(rp) \
			-llType $val(ll) \
			-macType $val(mac) \
			-ifqType $val(ifq) \
			-ifqLen $val(ifqlen) \
			-antType $val(ant) \
			-propType $val(prop) \
			-phyType $val(netif) \
			-channelType $val(chan) \
			-topoInstance $topo \
			-agentTrace ON \
			-routerTrace OFF \
			-macTrace OFF \
			-movementTrace OFF			
			 
for {set i 0} {$i < $val(nn) } {incr i} {
	set node_($i) [$ns_ node]	
	$node_($i) random-motion 0		;# disable random motion
}


# Provide initial (X,Y, for now Z=0) co-ordinates for mobilenodes
$node_(0) set X_ 200.0
$node_(0) set Y_ 400.0
$node_(0) set Z_ 0.0

$node_(1) set X_ 500.0
$node_(1) set Y_ 400.0
$node_(1) set Z_ 0.0

$node_(2) set X_ 800.0
$node_(2) set Y_ 400.0
$node_(2) set Z_ 0.0

$node_(3) set X_ 200.0
$node_(3) set Y_ 200.0
$node_(3) set Z_ 0.0

$node_(4) set X_ 500.0
$node_(4) set Y_ 200.0
$node_(4) set Z_ 0.0

$node_(5) set X_ 800.0
$node_(5) set Y_ 200.0
$node_(5) set Z_ 0.0

# Define initial node size and color for Nam
$ns_ initial_node_pos $node_(0) 20
$ns_ initial_node_pos $node_(1) 20
$ns_ initial_node_pos $node_(2) 20
$ns_ initial_node_pos $node_(3) 20
$ns_ initial_node_pos $node_(4) 20
$ns_ initial_node_pos $node_(5) 20
$node_(0) color blue
$node_(1) color red
$node_(2) color green
$node_(3) color blue
$node_(4) color red
$node_(5) color green
$ns_ at 0.0 "$node_(0) color blue"
$ns_ at 0.0 "$node_(1) color red"
$ns_ at 0.0 "$node_(2) color green"
$ns_ at 0.0 "$node_(3) color blue"
$ns_ at 0.0 "$node_(4) color red"
$ns_ at 0.0 "$node_(5) color green"


# Setup traffic flow between nodes
# UDP connections
set udp0 [new Agent/UDP]
set udp1 [new Agent/UDP]
set udp2 [new Agent/UDP]
$ns_ attach-agent $node_(0) $udp0
$ns_ attach-agent $node_(1) $udp1
$ns_ attach-agent $node_(2) $udp2
set null0 [new Agent/Null]
set null1 [new Agent/Null]
set null2 [new Agent/Null]
$ns_ attach-agent $node_(3) $null0
$ns_ attach-agent $node_(4) $null1
$ns_ attach-agent $node_(5) $null2
$ns_ connect $udp0 $null0
$ns_ connect $udp1 $null1
$ns_ connect $udp2 $null2
$udp0 set packetSize_ 1500
$udp1 set packetSize_ 1500
$udp2 set packetSize_ 1500
$udp0 set class_ 2
$udp1 set class_ 2
$udp2 set class_ 2

# CBR traffic generation
set cbr0 [new Application/Traffic/CBR]
set cbr1 [new Application/Traffic/CBR]
set cbr2 [new Application/Traffic/CBR]
$cbr0 attach-agent $udp0
$cbr1 attach-agent $udp1
$cbr2 attach-agent $udp2
$cbr0 set packetSize_ 1500
$cbr1 set packetSize_ 1500
$cbr2 set packetSize_ 1500
$cbr0 set rate_ 6.0Mb
$cbr1 set rate_ 6.0Mb
$cbr2 set rate_ 6.0Mb
$ns_ at 1.0 "$cbr0 start"
$ns_ at 1.5 "$cbr1 start"
$ns_ at 1.0 "$cbr2 start"


# Tell nodes when the simulation ends
for {set i 0} {$i < $val(nn) } {incr i} {
    $ns_ at 10.0 "$node_($i) reset";
}

$ns_ at 10.0 "stop"
$ns_ at 10.01 "puts \"NS EXITING...\" ; $ns_ halt"
# No NAM trace, and write trace file 
proc stop {} {
    global ns_ tracefd tracenam outfile
    $ns_ flush-trace
    close $tracefd
    close $tracenam
    #exec nam $outfile.nam &
    exit 0
}

puts "Starting Simulation..."
$ns_ run


