##################
# Initialization
##################
set val(nbhops) 2;  # number of hops -> to change to simulate the different topologies

set val(simDur) 10.0 ;  # simulation duration

set val(basename)  multihop;  # basename for this scenario

set val(statIntvl) 0.1 ;  # statistics collection interval
set val(statStart) 1.0 ;


set val(chan)           [ new Channel/WirelessChannel]    ;# channel model
set val(prop)           Propagation/TwoRayGround   ;# radio-propagation model
set val(netif)          Phy/WirelessPhy            ;# network interface type
set val(mac)            Mac/802_11                 ;# MAC type
set val(ifq)            Queue/DropTail/PriQueue    ;# interface queue type
set val(ifqlen)         50                         ;# max packet in ifq
set val(ll)             LL                         ;# link layer type
set val(ant)            Antenna/OmniAntenna        ;# antenna model
set val(nn)             [expr $val(nbhops) + 1]    ;# number of mobilenodes
set val(rp)             AODV                       ;# routing protocol
set val(topo_x_dim)     200
set val(topo_y_dim)     [expr 100 + 200 * $val(nbhops)]



#######################################
# Initialize and create output files
# Create a simulator instance
#######################################
set ns [new Simulator]

#Crate a trace file and animation record
set tracefd [open $val(basename).tr w]
$ns trace-all $tracefd
set namtracefd [open $val(basename).nam w]
$ns namtrace-all-wireless $namtracefd $val(topo_x_dim) $val(topo_y_dim)

set outfd [open $val(basename).out w]



####################
# Create Topology
####################

# set up topography object
set topo       [new Topography]

$topo load_flatgrid $val(topo_x_dim) $val(topo_y_dim)

#
# Create God
#
create-god $val(nn)


# Add errors

#proc UniformErr {} {
#                set err [new ErrorModel]
#                $err unit packet
#                $err set rate_ 0.05
#                return $err
#}


#
#  Create the specified number of mobilenodes [$val(nn)] and "attach" them
#  to the channel.

$ns node-config -adhocRouting $val(rp) \
                 -llType $val(ll) \
                 -macType $val(mac) \
                 -ifqType $val(ifq) \
                 -ifqLen $val(ifqlen) \
                 -antType $val(ant) \
                 -propType $val(prop) \
                 -phyType $val(netif) \
                 -topoInstance $topo \
                 -agentTrace ON \
                 -routerTrace ON \
                 -macTrace ON \
                 -movementTrace OFF \
                 -channel $val(chan)
                 #-IncomingErrProc UniformErr ; # to add errors



for {set i 0} {$i < $val(nn) } {incr i} {
        set node($i) [$ns node]
        $node($i) random-motion 0              ;# disable random motion

        $node($i) set X_ [expr 50.0 + 200.0 * $i]
        $node($i) set Y_ 100.0
        $node($i) set Z_ 0.0

        $ns initial_node_pos $node($i) 20
}


##################
# Build scenario
##################
set src $node(0)
set dst $node($val(nbhops))

#########################

    #Create a tcp agent on the source node
    set tcp [new Agent/TCP]
    $tcp set class_ 2
    $ns attach-agent $src $tcp

    # Create a FTP traffic source on node0
    set ftp [new Application/FTP]
    $ftp attach-agent $tcp

    #Create a sink(a traffic sink) on the destination node
    set sink0 [new Agent/TCPSink]
    $ns attach-agent $dst $sink0

    #Connet source and dest Agents
    $ns connect $tcp $sink0
    $ns at $val(statStart) "$ftp start"



#########################
# a procedure to record stats
proc record {} {
    global sink0 ns outfd val
    set bytes [$sink0 set bytes_]
    set now [$ns now]
    puts $outfd "$now $bytes"
    $sink0 set bytes_ 0
    $ns at [expr $now+$val(statIntvl)] "record"
}


#########################
# a procedure to close trace file and nam file
proc finish {} {

        global ns tracefd namtracefd basename val
        $ns flush-trace

        close $tracefd
        close $namtracefd
        
        exit 0
}



#Schedule trigger events
$ns at $val(statStart) "record"

#Call the finish procedure after 5s (of simulated time)
$ns at $val(simDur) "finish"

#Run the simulation
$ns run




